@@ -1,4 +1,5 @@
 """Models for QA module."""
+from datetime import datetime
 from enum import Enum
 
 
@@ -17,7 +18,7 @@ class RunData:
 
     def __init__(
         self,
-        run_date: str,
+        run_date: datetime,
         duration: str,
         empower_env: str,
         run_link: str,
@@ -28,12 +29,13 @@ class RunData:
         success_records: int,
         failed_records: int,
         test_cases: list[TestCase],
+        record_status_counters: dict[str, int],
     ):
         """Initialize the run data."""
-        self.run_date = run_date
+        self.run_date: datetime = run_date
         self.duration = duration
         self.empower_env = empower_env
-        self.run_link = run_link
+        self.run_link: str = run_link
         self.status = status
         self.bugs = bugs
         self.code_coverage = code_coverage
@@ -41,6 +43,7 @@ class RunData:
         self.success_records = success_records
         self.failed_records = failed_records
         self.test_cases: list[TestCase] = test_cases
+        self.record_status_counters = record_status_counters
 
 
 class Color(str, Enum):
@@ -61,3 +64,24 @@ class Alignment(str, Enum):
 
     left = "LEFT"
     center = "CENTER"
+
+
+class DumpCell:
+    """Dump cell for the Excel file."""
+
+    def __init__(
+        self,
+        value: str,
+        row: int,
+        column_number: int,
+        color: str = None,
+        alignment: str = Alignment.left.value,
+        block_name: str = None,
+    ):
+        """Initialize the dump cell."""
+        self.row = row
+        self.block_name = block_name
+        self.column_number = column_number
+        self.value = value
+        self.bg_color = color
+        self.alignment = alignment
